@@ -9,7 +9,7 @@ do_test()
     assertEquals "$file1" "$file2"
 
 }
-test_expand_filename()
+test_pre_expand_filename()
 {
     do_test test-pre ./test-pre
     do_test "$PWD/" "${PWD}/."
@@ -18,23 +18,22 @@ test_expand_filename()
     do_test "$file1" ~
 }
 
-test_do_show_version()
+test_pre_do_show_version()
 {
     # Name we refer to ourselves by
     typeset _Dbg_debugger_name='bashdb'
     # The release name we are configured to run under.
-    typeset _Dbg_release='4.0-0.3'
+    typeset _Dbg_release='4.3-0.91'
 
-    version_string=$(_Dbg_do_show_version)
-    assertEquals "bashdb, release 4.0-0.3" "$version_string"
+    version_string=$(_Dbg_do_show_version 2>&1)
+    assertEquals "bashdb, release 4.3-0.91" "$version_string"
 }
-abs_top_srcdir=/src/external-vcs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+# Make sure $abs_top_srcdir has a trailing slash
+abs_top_srcdir=${abs_top_srcdir%%/}/
+. ${abs_top_srcdir}test/unit/helper.sh
+. ${abs_top_srcdir}/init/pre.sh
+set -- # reset $# so shunit2 doesn't get confused.
 
-_Dbg_libdir=$abs_top_srcdir
-set -- -q  # Don't need to show banner
-
-. ${abs_top_srcdir}/dbg-pre.sh
-
-# load shunit2
-. ${abs_top_srcdir}/test/unit/shunit2
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
 
